@@ -1,9 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * cdrom.c
+ *  Authors: Iain Holmes <iain@ximian.com>
+ *
+ *  Copyright 2001 Iain Holmes
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- * Copyright (C) 2001 Iain Holmes
- * Authors: Iain Holmes <iain@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -404,7 +418,7 @@ static void
 cdrom_update_cd (GnomeCDRom *cdrom)
 
 {
-	g_error ("cdrom_update_cd not implmented");
+	g_error ("cdrom_update_cd not implemented");
 }
 
 static void
@@ -790,7 +804,8 @@ timeout_update_cd (gpointer data)
 		if (priv->update != GNOME_CDROM_UPDATE_NEVER)
 			gnome_cdrom_status_changed (GNOME_CDROM (cdrom), priv->recent_status);
 		gcd_warning ("%s", error);
-		g_error_free (error);
+		if (error)
+			g_error_free (error);
 		g_object_unref (G_OBJECT (cdrom));
 
 		return TRUE;
