@@ -663,7 +663,8 @@ add_stream (GvcMixerDialog *dialog,
                 g_debug ("Adding effects stream");
         } else if (! GVC_IS_MIXER_SOURCE (stream)
                    && !GVC_IS_MIXER_SINK (stream)
-                   && !GVC_IS_MIXER_SOURCE_OUTPUT (stream)) {
+                   && !GVC_IS_MIXER_SOURCE_OUTPUT (stream)
+                   && !gvc_mixer_stream_is_event_stream (stream)) {
                 bar = create_bar (dialog, dialog->priv->apps_size_group, FALSE);
                 gvc_channel_bar_set_name (GVC_CHANNEL_BAR (bar),
                                           gvc_mixer_stream_get_name (stream));
@@ -983,6 +984,7 @@ gvc_mixer_dialog_constructor (GType                  type,
         object = G_OBJECT_CLASS (gvc_mixer_dialog_parent_class)->constructor (type, n_construct_properties, construct_params);
 
         self = GVC_MIXER_DIALOG (object);
+        gtk_dialog_add_button (GTK_DIALOG (self), "gtk-close", GTK_RESPONSE_OK);
 
 #if GTK_CHECK_VERSION(2,14,0)
         main_vbox = gtk_dialog_get_content_area (GTK_DIALOG (self));
@@ -990,7 +992,7 @@ gvc_mixer_dialog_constructor (GType                  type,
         main_vbox = GTK_DIALOG (self)->vbox;
 #endif
 
-        gtk_container_set_border_width (GTK_CONTAINER (self), 12);
+        gtk_container_set_border_width (GTK_CONTAINER (self), 6);
 
         self->priv->output_stream_box = gtk_hbox_new (FALSE, 12);
         gtk_box_pack_start (GTK_BOX (main_vbox),
@@ -1006,7 +1008,7 @@ gvc_mixer_dialog_constructor (GType                  type,
         self->priv->notebook = gtk_notebook_new ();
         gtk_box_pack_start (GTK_BOX (main_vbox),
                             self->priv->notebook,
-                            TRUE, TRUE, 12);
+                            TRUE, TRUE, 6);
 
         /* Effects page */
         self->priv->sound_effects_box = gtk_vbox_new (FALSE, 6);
@@ -1026,7 +1028,7 @@ gvc_mixer_dialog_constructor (GType                  type,
         self->priv->sound_theme_chooser = gvc_sound_theme_chooser_new ();
         gtk_box_pack_start (GTK_BOX (self->priv->sound_effects_box),
                             self->priv->sound_theme_chooser,
-                            TRUE, TRUE, 0);
+                            TRUE, TRUE, 6);
 
         /* Input page */
         self->priv->input_box = gtk_vbox_new (FALSE, 12);
@@ -1156,8 +1158,6 @@ gvc_mixer_dialog_constructor (GType                  type,
                             self->priv->no_apps_label,
                             TRUE, TRUE, 0);
 
-        gtk_widget_show_all (GTK_WIDGET (self));
-
         g_signal_connect (self->priv->mixer_control,
                           "stream-added",
                           G_CALLBACK (on_control_stream_added),
@@ -1167,6 +1167,8 @@ gvc_mixer_dialog_constructor (GType                  type,
                           G_CALLBACK (on_control_stream_removed),
                           self);
 
+        gtk_widget_show_all (GTK_WIDGET (self));
+
         streams = gvc_mixer_control_get_streams (self->priv->mixer_control);
         for (l = streams; l != NULL; l = l->next) {
                 stream = l->data;
