@@ -82,7 +82,11 @@ popup_dock (GvcStreamStatusIcon *icon,
         GdkScreen     *screen;
         gboolean       is_muted;
         gboolean       res;
-        int            x, y;
+        int            x;
+        int            y;
+        int            monitor_num;
+        GdkRectangle   monitor;
+        GtkRequisition dock_req;
 
         adj = GTK_ADJUSTMENT (gvc_channel_bar_get_adjustment (GVC_CHANNEL_BAR (icon->priv->bar)));
         gtk_adjustment_set_value (adj,
@@ -102,15 +106,40 @@ popup_dock (GvcStreamStatusIcon *icon,
 
         /* position roughly */
         gtk_window_set_screen (GTK_WINDOW (icon->priv->dock), screen);
-        x = area.x + area.width;
-        y = area.y + area.height;
+        gvc_channel_bar_set_orientation (GVC_CHANNEL_BAR (icon->priv->bar),
+                                         1 - orientation);
+
+        monitor_num = gdk_screen_get_monitor_at_point (screen, area.x, area.y);
+        gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+
+        gtk_widget_size_request (icon->priv->dock, &dock_req);
 
         if (orientation == GTK_ORIENTATION_VERTICAL) {
-                gtk_window_move (GTK_WINDOW (icon->priv->dock), x, area.y);
+                if (area.x + area.width + dock_req.width <= monitor.x + monitor.width) {
+                        x = area.x + area.width;
+                } else {
+                        x = area.x - dock_req.width;
+                }
+                if (area.y + dock_req.height <= monitor.y + monitor.height) {
+                        y = area.y;
+                } else {
+                        y = monitor.y + monitor.height - dock_req.height;
+                }
         } else {
-                gtk_window_move (GTK_WINDOW (icon->priv->dock), area.x, y);
+                if (area.y + area.height + dock_req.height <= monitor.y + monitor.height) {
+                        y = area.y + area.height;
+                } else {
+                        y = area.y - dock_req.height;
+                }
+                if (area.x + dock_req.width <= monitor.x + monitor.width) {
+                        x = area.x;
+                } else {
+                        x = monitor.x + monitor.width - dock_req.width;
+                }
         }
 
+        gtk_window_move (GTK_WINDOW (icon->priv->dock), x, y);
+
         /* FIXME: without this, the popup window appears as a square
          * after changing the orientation
          */
@@ -146,12 +175,21 @@ popup_dock (GvcStreamStatusIcon *icon,
 }
 
 static void
-on_status_icon_activate (GtkStatusIcon *status_icon,
-                         GvcStreamStatusIcon     *icon)
+on_status_icon_activate (GtkStatusIcon       *status_icon,
+                         GvcStreamStatusIcon *icon)
 {
         popup_dock (icon, GDK_CURRENT_TIME);
 }
 
+static void
+on_menu_mute_toggled (GtkMenuItem         *item,
+                      GvcStreamStatusIcon *icon)
+{
+        gboolean is_muted;
+        is_muted = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item));
+        gvc_channel_bar_set_is_muted (GVC_CHANNEL_BAR (icon->priv->bar), is_muted);
+}
+
 static void
 on_menu_activate_open_volume_control (GtkMenuItem *item,
                                       GvcStreamStatusIcon   *icon)
@@ -192,6 +230,16 @@ on_status_icon_popup_menu (GtkStatusIcon       *status_icon,
         GtkWidget *image;
 
         menu = gtk_menu_new ();
+
+        item = gtk_check_menu_item_new_with_mnemonic (_("_Mute"));
+        gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
+                                        gvc_mixer_stream_get_is_muted (icon->priv->mixer_stream));
+        g_signal_connect (item,
+                          "toggled",
+                          G_CALLBACK (on_menu_mute_toggled),
+                          icon);
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
         item = gtk_image_menu_item_new_with_mnemonic (_("_Sound Preferences"));
         image = gtk_image_new_from_icon_name ("multimedia-volume-control",
                                               GTK_ICON_SIZE_MENU);
@@ -640,7 +688,7 @@ gvc_stream_status_icon_constructor (GType                  type,
         gtk_widget_show (frame);
 
         box = gtk_vbox_new (FALSE, 6);
-        gtk_container_set_border_width (GTK_CONTAINER (box), 6);
+        gtk_container_set_border_width (GTK_CONTAINER (box), 2);
         gtk_container_add (GTK_CONTAINER (frame), box);
 
         icon->priv->bar = gvc_channel_bar_new ();
